@@ -36,9 +36,10 @@
 void
 dmfn_daemonize (void)
 {
-    int  i_res = fork ();
+    int  i_res = 0;
     long i     = 0;
 
+    i_res = fork ();
     if (i_res > 0)
         exit (EXIT_SUCCESS);
     else if (i_res < 0)
@@ -114,7 +115,7 @@ dmfn_start (void)
 /**
  * @brief  Kill wchangerd process
  */
-void
+int
 dmfn_kill (void)
 {
     int i_cnt = 0;
@@ -127,6 +128,7 @@ dmfn_kill (void)
     else {
         printf ("Could not find wchangerd\n");
     }
+    return i_cnt;
 }
 /*----------------------------------------------------------------------------*/
 
