@@ -30,7 +30,7 @@
 #ifndef RANDOMM_H
 #define RANDOMM_H
 
-#define RMMAX 1000  /**< RMMAX * 32 maximum random number range */
+#define RMMAX 500  /**< RMMAX * 32 maximum random number range */
 
 #include <stdint.h>
 /*----------------------------------------------------------------------------*/
@@ -71,6 +71,21 @@ void randomm_clear (RandMem *rm_mem);
  */
 void randomm_init (RandMem *rm_mem);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Create new RandMem item.
+ *
+ * @return New RandMem item
+ */
+RandMem * randomm_new (void) __attribute__((malloc));
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Free RandMem item.
+ *
+ * @param[out] rm_mem  RandMem object
+ * @return     none
+ */
+void randomm_free (RandMem *rm_mem);
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set random numbers maximum range.
  *
