@@ -18,7 +18,7 @@
  * along with Wall Changer.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @brief  String operations 
- * 
+ *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #include <stdlib.h>
@@ -55,28 +55,6 @@ str_compare (const char *a,
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Creates string with name made of s_name string and number
- *         ul_no at the end.
- */ 
-char *
-str_name_with_number (const char   *s_name,
-                      const size_t  ul_no)
-{
-    char   *s_res  = NULL;   /* Result string */
-    size_t  ul_tmp = ul_no;  /* Copy of number */
-    size_t  ul_l   = 1;      /* Length of number string */
-
-    while (ul_tmp /= 10)
-        ul_l++;
-
-    cres ((void**) &s_res, strlen (s_name) + ul_l + 1, sizeof (char));
-
-    sprintf (s_res, "%s%ld", s_name, ul_no);
-
-    return s_res;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Replace one string with another in a given src_dest string.
  */ 
@@ -197,23 +175,17 @@ str_append (char       **s_dst,
 {
     size_t ui_dst = 0; /* length of dst string */
     size_t ui_src = 0; /* Length of src string */
-    int    i_zero = 0; /* Place 0 in new string */
 
     if (s_src == NULL)
         return;
     else
         ui_src = strlen (s_src);
 
-    if (*s_dst == NULL)
-        i_zero = 1;
-    else
+    if (*s_dst != NULL)
         ui_dst = strlen (*s_dst);
 
     cres ((void**) s_dst, ui_src + ui_dst + 1, sizeof (char));
 
-    if (i_zero)
-        *s_dst[0] = '\0';
-
     memcpy ((*s_dst)+ui_dst, s_src, ui_src);
     (*s_dst)[ui_src+ui_dst] = '\0';
 }
